package com.lantone.qc.kernel.structure.ai.process;

import com.alibaba.fastjson.JSONObject;
import com.lantone.qc.kernel.structure.ai.model.EntityEnum;
import com.lantone.qc.kernel.structure.ai.model.Lemma;
import com.lantone.qc.pub.model.entity.Chief;
import com.lantone.qc.pub.model.entity.DoctorAdvice;
import com.lantone.qc.pub.model.entity.Notes;
import com.lantone.qc.pub.model.entity.Outcome;
import com.lantone.qc.pub.model.label.LeaveHospitalLabel;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName : EntityProcessLeaveHospital
 * @Description : 出院小结
 * @Author : 胡敬
 * @Date: 2020-03-20 11:20
 */
public class EntityProcessLeaveHospital extends EntityProcess {
    public LeaveHospitalLabel extractEntity(JSONObject aiOut) {
        LeaveHospitalLabel leaveHospitalLabel = new LeaveHospitalLabel();
        //主诉
        List<Lemma> chiefLemmas = createEntityTree(aiOut, EntityEnum.CHIEF.toString());
        List<Chief> chiefs = new ArrayList<>();
        for (Lemma lemma : chiefLemmas) {
            Chief chief = new Chief();
            chief.setName(lemma.getText());
            chiefs.add(chief);
        }
        leaveHospitalLabel.setChiefs(chiefs);
        //注意事项
        List<Lemma> notesLemmas = createEntityTree(aiOut, EntityEnum.NOTES.toString());
        List<Notes> noteses = new ArrayList<>();
        for (Lemma lemma : notesLemmas) {
            Notes notes = new Notes();
            notes.setName(lemma.getText());
            noteses.add(notes);
        }
        leaveHospitalLabel.setNoteses(noteses);
        //医嘱
        List<Lemma> keyWordForDoctorAdvicesesLemmas = createEntityTree(aiOut, EntityEnum.KEY_WORD_FOR_DOCTOR_ADVICES.toString());
        List<Lemma> keyWordForPartLemmas = createEntityTree(aiOut, EntityEnum.KEY_WORD_FOR_PART.toString());
        DoctorAdvice doctorAdvice = new DoctorAdvice();
        int keyWordForDoctorAdvicesesStart = 0, partStart = 0, minPart = 0;
        for (Lemma doctorAdviceLemma : keyWordForDoctorAdvicesesLemmas) {
            keyWordForDoctorAdvicesesStart = Integer.parseInt(doctorAdviceLemma.getPosition());
            for (Lemma part : keyWordForPartLemmas) {
                partStart = Integer.parseInt(part.getPosition());
                if (minPart == 0 || partStart > keyWordForDoctorAdvicesesStart && partStart < minPart) {
                    minPart = partStart;
                }
            }
        }
        String content = aiOut.getString("content");
        String doctorAdviceContent = content.substring(keyWordForDoctorAdvicesesStart, minPart);
        doctorAdvice.setName(doctorAdviceContent);
        leaveHospitalLabel.setDoctorAdvices(doctorAdvice);
        //转归情况
        List<Lemma> outcomeLemmas = createEntityTree(aiOut, EntityEnum.OUTCOME.toString());
        List<Outcome> outcomes = new ArrayList<>();
        for (Lemma lemma : outcomeLemmas) {
            Outcome outcome = new Outcome();
            outcome.setName(lemma.getText());
            outcomes.add(outcome);
        }
        leaveHospitalLabel.setOutcomes(outcomes);
        return leaveHospitalLabel;
    }
}