package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.keys.ModelStandardKeys;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

/**
 * @Description: 首次病程录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:25
 */
public class ChangxFirstCourseRecordDocTrans extends ModelDocTrans {

    @Override
    public FirstCourseRecordDoc extract(MedrecVo medrecVo) {
        String content = ((List<String>) medrecVo.getContent().get("content")).get(0);

        List<String> targetTitles = Lists.newArrayList();
        List<String> sourceTitles = ListUtil.isEmpty(medrecVo.getLabel()) ? ModelStandardKeys.firstCourseRecord : medrecVo.getLabel();
        sourceTitles.forEach(sourceTitle -> {
            String targetTitle = "[一二三四五六七八九十]{0,1}[、.]{0,1}";
            for (int index = 0; index < sourceTitle.length(); index++) {
                if (index == sourceTitle.length() - 1) {
                    targetTitle += sourceTitle.substring(index, index + 1);
                } else {
                    targetTitle += sourceTitle.substring(index, index + 1) + "[\\s\\p{Zs}]*";
                }
            }
            targetTitles.add(targetTitle);
        });

        Map<String, String> sourceMap = Preproc.extract_doc_pub(false, targetTitles, content);
        sourceMap.put("病程记录内容",
                sourceMap.get("病程记录内容")
                        .replace(sourceMap.get("病程记录时间"), "")
                        .replace(sourceMap.get("病程记录名称"), "")
        );

        Map<String, String> targetMap = Maps.newHashMap();
        Map<String, Object> pageData = Maps.newHashMap();
        for (String key : sourceMap.keySet()) {
            if (key.equals("病程记录时间")) {
                targetMap.put("记录时间", sourceMap.get(key));
            } else {
                targetMap.put(key.replaceAll("[一二三四五六七八九十][、.]", ""), sourceMap.get(key));
            }
            pageData.put(key.replaceAll("[一二三四五六七八九十][、.]", ""), sourceMap.get(key));
        }

        FirstCourseRecordDoc firstCourseRecordDoc = ModelDocGenerate.firstCourseRecordDocGen(targetMap);
        firstCourseRecordDoc.setText(content);
        firstCourseRecordDoc.setPageData(pageData);

        return firstCourseRecordDoc;
    }

}